@@ -80,7 +80,7 @@ PrintPainter::PrintPainter(KTextEditor::DocumentPrivate *doc, KTextEditor::ViewP
     , m_headerFormat()
     , m_footerFormat()
 {
-    m_renderer = new KateRenderer(m_doc, m_view->renderer()->folding(), m_view);
+    m_renderer = new KateRenderer(doc, view->renderer()->folding(), view);
     m_renderer->setPrinterFriendly(true);
 
     updateCache();
@@ -93,7 +93,7 @@ PrintPainter::~PrintPainter()
 
 void PrintPainter::setTextFont(const QFont &font)
 {
-    m_view->rendererConfig()->setFont(font);
+    m_renderer->config()->setFont(font);
 }
 
 void PrintPainter::setUseBox(const bool on)
@@ -151,7 +151,7 @@ void PrintPainter::setFooterForeground(const QColor &color)
 void PrintPainter::setColorScheme(const QString &scheme)
 {
     // directly set that for the renderer
-    m_view->rendererConfig()->setSchema(scheme);
+    m_renderer->config()->setSchema(scheme);
 
     // changed renderer requires cache updates
     updateCache();
@@ -181,7 +181,7 @@ void PrintPainter::paint(QPrinter *printer) const
     bool pageStarted = true;
     uint remainder = 0;
 
-    auto &f = m_view->renderer()->folding();
+    auto &f = m_renderer->folding();
 
     // On to draw something :-)
     while (lineCount <= pl.lastline) {
@@ -365,9 +365,9 @@ void PrintPainter::configure(const QPrinter *printer, PageLayout &pl) const
         int totalLines = 0;
         // TODO: right now ignores selection printing
         for (unsigned int i = pl.firstline; i <= pl.lastline; ++i) {
-            KateLineLayout rangeptr(*m_renderer);
-            rangeptr.setLine(i);
-            m_renderer->layoutLine(&rangeptr, (int)pl.maxWidth, false);
+            KateLineLayout rangeptr;
+            rangeptr.setLine(m_renderer->folding(), i);
+            m_renderer->layoutLine(m_renderer->doc()->kateTextLine(rangeptr.line()), &rangeptr, (int)pl.maxWidth, false);
             totalLines += rangeptr.viewLineCount();
         }
 
@@ -495,7 +495,7 @@ void PrintPainter::paintGuide(QPainter &painter, uint &y, const PageLayout &pl)
     QString _hlName = m_doc->highlight()->name();
 
     // list of highlight attributes for the legend
-    const auto _attributes = m_doc->highlight()->attributesForDefinition(m_view->rendererConfig()->schema());
+    const auto _attributes = m_doc->highlight()->attributesForDefinition(m_renderer->config()->schema());
     const QColor _defaultPen = _attributes.at(0)->foreground().color();
 
     painter.save();
@@ -629,15 +629,15 @@ void PrintPainter::paintBackground(QPainter &painter, const uint y, const PageLa
             _h += pl.innerMargin;
         }
     }
-    painter.fillRect(0, _y, pl.pageWidth, _h, m_view->rendererConfig()->backgroundColor());
+    painter.fillRect(0, _y, pl.pageWidth, _h, m_renderer->config()->backgroundColor());
 }
 
 void PrintPainter::paintLine(QPainter &painter, const uint line, uint &y, uint &remainder, const PageLayout &pl) const
 {
     // HA! this is where we print [part of] a line ;]]
-    KateLineLayout rangeptr(*m_renderer);
-    rangeptr.setLine(line);
-    m_renderer->layoutLine(&rangeptr, (int)pl.maxWidth, false);
+    KateLineLayout rangeptr;
+    rangeptr.setLine(m_renderer->folding(), line);
+    m_renderer->layoutLine(m_renderer->doc()->kateTextLine(rangeptr.line()), &rangeptr, (int)pl.maxWidth, false);
 
     // selectionOnly: clip non-selection parts and adjust painter position if needed
     int _xadjust = 0;
@@ -653,12 +653,24 @@ void PrintPainter::paintLine(QPainter &painter, const uint line, uint &y, uint &
             QRegion region(0, 0, pl.maxWidth, rangeptr.viewLineCount() * m_fontHeight);
 
             if (line == pl.firstline) {
-                region = region.subtracted(QRegion(0, 0, m_renderer->cursorToX(rangeptr.viewLine(0), pl.selectionRange.start()), m_fontHeight));
+                int l = rangeptr.viewLineForColumn(pl.selectionRange.start().column());
+                // clip viewlines above the selection
+                for (int vl = 0; vl < l; ++vl) {
+                    region = region.subtracted(QRegion(0, vl * m_fontHeight, pl.maxWidth, m_fontHeight));
+                }
+                region = region.subtracted(QRegion(0, 0, m_renderer->cursorToX(rangeptr.viewLine(l), pl.selectionRange.start()), m_fontHeight));
             }
 
             if (line == pl.lastline) {
-                int _x = m_renderer->cursorToX(rangeptr.viewLine(rangeptr.viewLineCount() - 1), pl.selectionRange.end());
-                region = region.subtracted(QRegion(_x, 0, pl.maxWidth - _x, m_fontHeight));
+                int vl = rangeptr.viewLineForColumn(pl.selectionRange.end().column());
+                int x = m_renderer->cursorToX(rangeptr.viewLine(vl), pl.selectionRange.end());
+                // clip the unnecessary portion of this line
+                region = region.subtracted(QRegion(x, (vl)*m_fontHeight, pl.maxWidth - x, m_fontHeight));
+                vl++;
+                // and the viewlines below
+                for (; vl < rangeptr.viewLineCount(); ++vl) {
+                    region = region.subtracted(QRegion(0, vl * m_fontHeight, pl.maxWidth, m_fontHeight));
+                }
             }
 
             painter.setClipRegion(region);
@@ -706,7 +718,7 @@ void PrintPainter::paintLineNumber(QPainter &painter, const uint number, const P
 
     painter.save();
     painter.setFont(m_renderer->currentFont());
-    painter.setPen(m_view->rendererConfig()->lineNumberColor());
+    painter.setPen(m_renderer->config()->lineNumberColor());
     painter.drawText(left, 0, m_lineNumberWidth, m_fontHeight, Qt::AlignRight | Qt::AlignVCenter, QString::number(number + 1));
     painter.restore();
 }
