@@ -6,6 +6,9 @@
 
 #include "ktexteditor/message.h"
 
+#include <QAction>
+#include <QIcon>
+
 namespace KTextEditor
 {
 class MessagePrivate
@@ -33,7 +36,7 @@ Message::Message(const QString &richtext, MessageType type)
 
 Message::~Message()
 {
-    emit closed(this);
+    Q_EMIT closed(this);
 
     delete d;
 }
@@ -47,14 +50,14 @@ void Message::setText(const QString &text)
 {
     if (d->text != text) {
         d->text = text;
-        emit textChanged(text);
+        Q_EMIT textChanged(text);
     }
 }
 
 void Message::setIcon(const QIcon &newIcon)
 {
     d->icon = newIcon;
-    emit iconChanged(d->icon);
+    Q_EMIT iconChanged(d->icon);
 }
 
 QIcon Message::icon() const
@@ -75,7 +78,7 @@ void Message::addAction(QAction *action, bool closeOnTrigger)
 
     // call close if wanted
     if (closeOnTrigger) {
-        connect(action, SIGNAL(triggered()), SLOT(deleteLater()));
+        connect(action, &QAction::triggered, this, &QObject::deleteLater);
     }
 }
 
